@@ -23,7 +23,7 @@ from pandas.io.json._json import JsonReader
 from pandas.io.parsers import TextFileReader
 from pydantic.alias_generators import to_snake
 
-from superlinked.framework.common.telemetry.telemetry_registry import telemetry
+from superlinked.framework.common.telemetry.telemetry_registry import TelemetryAttributeType, telemetry
 from superlinked.framework.dsl.source.data_loader_source import (
     DataFormat,
     DataLoaderConfig,
@@ -52,12 +52,12 @@ class DataLoader:
     def get_data_loaders(self) -> dict[str, DataLoaderConfig]:
         return {name: source.config for name, source in self._data_loader_sources.items()}
 
-    def load(self, name: str) -> None:
+    async def load(self, name: str) -> None:
         data_loader_source = self._data_loader_sources.get(name)
         if not data_loader_source:
             msg = f"Data loader with name: {name} not found"
             raise DataLoaderNotFoundException(msg)
-        task = asyncio.create_task(asyncio.to_thread(self.__read_and_put_data, data_loader_source))
+        task = asyncio.create_task(self.__read_and_put_data(data_loader_source))
         task.add_done_callback(self._task_done_callback)
         logger.info(
             "started data load",
@@ -65,32 +65,27 @@ class DataLoader:
             task_name=task.get_name(),
         )
 
-    def __read_and_put_data(self, source: DataLoaderSource) -> None:
+    async def __read_and_put_data(self, source: DataLoaderSource) -> None:
         data = self.__read_data(source.config.path, source.config.format, source.config.pandas_read_kwargs)
+        labels: dict[str, TelemetryAttributeType] = {
+            "data_loader_name": source.name,
+            "schema": source._schema._schema_name,
+            "data_format": source.config.format.value,
+            "chunked": False,
+        }
         if isinstance(data, pd.DataFrame):
             self.__print_memory_usage(data)
             logger.debug("loaded data frame to memory", chunked=False, size=len(data))
-            labels = {
-                "data_loader_name": source.name,
-                "schema": source._schema,
-                "data_format": source.config.format.value,
-                "chunked": False,
-            }
             with telemetry.span("data_loader.put", attributes=labels):
-                source.put([data])
+                await source.put_async([data])
             telemetry.record_metric("ingested_items_with_data_loader_total", len(data), labels=labels)
         elif isinstance(data, TextFileReader | JsonReader):
             for chunk in data:
                 self.__print_memory_usage(chunk)
                 logger.debug("loaded data frame to memory", chunked=True, size=len(chunk))
-                labels = {
-                    "data_loader_name": source.name,
-                    "schema": source._schema,
-                    "data_format": source.config.format.value,
-                    "chunked": True,
-                }
+                labels["chunked"] = True
                 with telemetry.span("data_loader.put", attributes=labels):
-                    source.put([chunk])
+                    await source.put_async([chunk])
                 telemetry.record_metric("ingested_items_with_data_loader_total", len(chunk), labels=labels)
         else:
             error_message = (
@@ -130,7 +125,7 @@ class DataLoader:
                 msg = "Unsupported data format: %s"
                 raise ValueError(msg, data_format)
 
-    # TODO: This is printing not logging the data. See FAI-2328
+    # TODO FAI-2328: This is printing not logging the data.
     def __print_memory_usage(self, df: pd.DataFrame) -> None:
         if logging.getLogger().isEnabledFor(logging.DEBUG):
             df.info(memory_usage=True)
